@@ -2,7 +2,7 @@ from .ac_basic import nearfield, eba, vol_samp, footprint_radius, footprint_area
 from .get_bd import get_bd
 from .get_gps import get_gps
 from .get_mlsv import logmean, get_MLSv, ncToPiv2D
-from .get_Sv import get_Sv, get_active_radius
+from .get_Sv import get_Sv, get_active_dives
 from .help_fun import haversine, compute_c, alpha_FrancoisGarrison, tvg
 from .kml2 import get_kml_track
 from .log_update import getSatFile, sat2log
